@@ -11,7 +11,6 @@ from collections import defaultdict
 import numpy as np
 import yaml
 from future.utils import raise_from
-
 # try to use LibYAML bindings if possible
 try:
     from yaml import CLoader as Loader, CSafeDumper as Dumper
@@ -19,6 +18,7 @@ except ImportError:
     from yaml import Loader, SafeDumper as Dumper
 from yaml.representer import SafeRepresenter
 
+from hepdata_validator.full_submission_validator import FullSubmissionValidator
 from hepdata_lib import helpers
 from hepdata_lib.root_utils import RootFileReader
 
@@ -46,7 +46,7 @@ yaml.add_representer(np.str_,
 # Display deprecation warnings
 warnings.filterwarnings("always", category=DeprecationWarning, module="hepdata_lib")
 
-__version__ = "0.9.0"
+__version__ = "0.10.0"
 
 class AdditionalResourceMixin(object):
     """Functionality related to additional materials."""
@@ -358,26 +358,39 @@ class Table(AdditionalResourceMixin):
                 raise RuntimeError("File %s does not exist!" % image_file)
             if not os.path.exists(outdir):
                 os.makedirs(outdir)
-            out_image_file = "{}.png".format(
-                os.path.splitext(image_file)[0].rsplit("/", 1)[1])
-            thumb_out_image_file = "thumb_" + out_image_file
-            # first convert to png, then create thumbnail
-            command = "convert -flatten -density 300 -fuzz 1% -trim +repage {} {}/{}".format(
-                image_file, outdir, out_image_file)
-            command_ok = helpers.execute_command(command)
-            if not command_ok:
-                print("ImageMagick does not seem to be installed \
-                       or is not in the path - not adding any images.")
-                break
-            command = "convert -thumbnail 240x179 {outdir}/{image} {outdir}/{thumb}".format(
-                outdir=outdir, image=out_image_file, thumb=thumb_out_image_file)
-            helpers.execute_command(command)
+
+            # PNG file is named same as input file except for extension
+            # Thumbnail is named with a '_thumb' prefix
+            png_output_base = os.path.splitext(os.path.basename(image_file))[0] + ".png"
+            thumbnail_output_base = "thumb_" + png_output_base
+
+            # Absolute paths for further use
+            png_output_path = os.path.join(outdir, png_output_base)
+            thumbnail_output_path = os.path.join(outdir, thumbnail_output_base)
+
+
+            # Convert to full-size PNG image
+            # Only executed if output is missing or out of date
+            if helpers.file_is_outdated(png_output_path, image_file):
+                helpers.convert_pdf_to_png(image_file, png_output_path)
+            else:
+                print("Full-size PNG file %s is newer than its source file. \
+                       Remove the thumbnail file or use create_files(remove_old=True)\
+                           to force recreation." % png_output_path)
+
+            if helpers.file_is_outdated(thumbnail_output_path, png_output_path):
+                helpers.convert_png_to_thumbnail(png_output_path, thumbnail_output_path)
+            else:
+                print("Thumbnail PNG file %s is newer than its source file. \
+                       Remove the thumbnail file or use create_files(remove_old=True)\
+                           to force recreation." % thumbnail_output_path)
+
             image = {}
             image["description"] = "Image file"
-            image["location"] = out_image_file
+            image["location"] = os.path.basename(png_output_path)
             thumbnail = {}
             thumbnail["description"] = "Thumbnail image file"
-            thumbnail["location"] = thumb_out_image_file
+            thumbnail["location"] = os.path.basename(thumbnail_output_path)
             self.additional_resources.append(image)
             self.additional_resources.append(thumbnail)
 
@@ -525,13 +538,21 @@ class Submission(AdditionalResourceMixin):
             files = files + table.files_to_copy
         return files
 
-    def create_files(self, outdir="."):
+    def create_files(self, outdir=".", validate=True, remove_old=True):
         """
         Create the output files.
 
         Implicitly triggers file creation for all tables that have been added to the submission,
         all variables associated to the tables and all uncertainties associated to the variables.
+
+        If `validate` is True, the hepdata-validator package will be used to validate the
+        output tar ball.
+
+        If `remove_old` is True, the output directory will be deleted before recreation.
         """
+        if remove_old and os.path.exists(outdir):
+            shutil.rmtree(outdir)
+
         if not os.path.exists(outdir):
             os.makedirs(outdir)
 
@@ -567,13 +588,21 @@ class Submission(AdditionalResourceMixin):
         files_to_add.extend(
             [os.path.join(outdir, os.path.basename(x)) for x in  self.files_to_copy_nested()]
         )
-        with tarfile.open("submission.tar.gz", "w:gz") as tar:
+        tarfile_path = "submission.tar.gz"
+        with tarfile.open(tarfile_path, "w:gz") as tar:
             for filepath in files_to_add:
                 tar.add(
                         filepath,
                         arcname=os.path.basename(filepath)
                         )
 
+        if validate:
+            full_submission_validator = FullSubmissionValidator()
+            is_archive_valid = full_submission_validator.validate(archive=tarfile_path)
+            if not is_archive_valid:
+                for filename in full_submission_validator.get_messages():
+                    full_submission_validator.print_errors(filename)
+            assert is_archive_valid, "The tar ball is not valid"
 
 class Uncertainty(object):
     """
